@@ -9,6 +9,7 @@
 import pilas
 from pilas import utils
 from pilas.estudiante import Estudiante
+import uuid
 
 IZQUIERDA = ["izquierda"]
 DERECHA = ["derecha"]
@@ -78,7 +79,7 @@ class Actor(object, Estudiante):
         self._actor = pilas.mundo.motor.obtener_actor(imagen, x=x, y=y)
         self.centro = ('centro', 'centro')
 
-        self.id = ""
+        self.id = uuid.uuid4()
 
         self.x = x
         self.y = y
@@ -277,9 +278,6 @@ class Actor(object, Estudiante):
         return self.obtener_imagen()
 
     def set_imagen(self, imagen):
-        if isinstance(imagen, str):
-            imagen = pilas.imagenes.cargar(imagen)
-
         self.definir_imagen(imagen)
 
     def get_fijo(self):
