@@ -51,6 +51,22 @@ class Control(object):
         >>> print pilas.mundo.control
         <Control izquierda: False derecha: False arriba: False abajo: False boton: False>
 
+    También tienes la posibilidad de crearte un control estableciendo las teclas
+    personalizadas.
+    Para ello debes crearte un diccionario con las claves izquierda, derecha,
+    arriba, abajo y boton.
+    Con las constantes de pilas.simbolos, puedes asignar una tecla a cada una
+    de las entradas del diccionario.
+    
+    
+    >>>    teclas = {pilas.simbolos.a: 'izquierda',
+                              pilas.simbolos.d: 'derecha',
+                              pilas.simbolos.w: 'arriba',
+                              pilas.simbolos.s: 'abajo',
+                              pilas.simbolos.ESPACIO: 'boton'}
+                
+    >>>    mi_control = pilas.control.Control(pilas.escena_actual(), teclas)
+    
 
     Consultando controles desde un actor:
 
@@ -77,7 +93,7 @@ class Control(object):
     .. image:: ../../pilas/data/patito.png
     """
 
-    def __init__(self, escena):
+    def __init__(self, escena, mapa_teclado=None):
         self.izquierda = False
         self.derecha = False
         self.arriba = False
@@ -86,6 +102,15 @@ class Control(object):
 
         escena.pulsa_tecla.conectar(self.cuando_pulsa_una_tecla)
         escena.suelta_tecla.conectar(self.cuando_suelta_una_tecla)
+        
+        if mapa_teclado == None:
+            self.mapa_teclado = {IZQUIERDA: 'izquierda',
+                                  DERECHA: 'derecha',
+                                  ARRIBA: 'arriba',
+                                  ABAJO: 'abajo',
+                                  ESPACIO: 'boton'}
+        else:
+            self.mapa_teclado = mapa_teclado
 
     def cuando_pulsa_una_tecla(self, evento):
         self.procesar_cambio_de_estado_en_la_tecla(evento.codigo, True)
@@ -94,16 +119,8 @@ class Control(object):
         self.procesar_cambio_de_estado_en_la_tecla(evento.codigo, False)
 
     def procesar_cambio_de_estado_en_la_tecla(self, codigo, estado):
-        mapa = {
-            IZQUIERDA: 'izquierda',
-            DERECHA: 'derecha',
-            ARRIBA: 'arriba',
-            ABAJO: 'abajo',
-            SELECCION: 'boton',
-        }
-
-        if mapa.has_key(codigo):
-            setattr(self, mapa[codigo], estado)
+        if self. mapa_teclado.has_key(codigo):
+            setattr(self, self. mapa_teclado[codigo], estado)
 
     def __str__(self):
         return "<Control izquierda: %s derecha: %s arriba: %s abajo: %s boton: %s>" %(
