@@ -1,8 +1,9 @@
-import pilas
 # Permite que este ejemplo funcion incluso si no has instalado pilas.
 import sys
 sys.path.insert(0, "..")
 
+import pilas
+
 pilas.iniciar()
-pilas.ejemplos.piezas.Piezas()
+pilas.cambiar_escena(pilas.demos.piezas.Piezas())
 pilas.ejecutar()
