@@ -18,15 +18,6 @@ fondo.agregar(montes, 0.5)
 fondo.agregar(arboles, 0.9)
 fondo.agregar(pasto, 2)
 
-"""
-# Mueve la posicion con un temporizador.
-def mover():
-    fondo.posicion += 3
-    return True
-                    
-pilas.mundo.tareas.siempre(1/15.0, mover)
-"""
-
-pilas.mundo.camara.x = [200], 10
+pilas.escena_actual().camara.x = [200], 10
 
 pilas.ejecutar()
